BP ChangeLog
============

BP 0.1.1-dev
------------

BP 0.1.1 (released on August 26, 2016)
--------------------------------------

* mucking around to make it actually pip installable...

BP 0.1 (released on August 26, 2016)
------------------------------------

* initial release. Not complete, but reasonably fast and memory efficient. This
    release was made as the object is minimally sufficient for its original
    intended use: optimization of UniFrac.
